==> mobi-5.x-1.0.tar.gz: mobi/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//WAPFORUM//DTD XHTML Mobile 1.2//EN" "http://www.openmobilealliance.org/tech/DTD/xhtml-mobile11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php print $head_title ?></title>
<style type="text/css">
  .header { background: #eef7fc; color: blue; border-bottom: solid 1px blue; margin: 0 0 5px 0; padding: 2px; }
  .footer { background: #eef7fc; color: blue; border-top: solid 1px blue; margin: 10px 0 0 0; }
  hr { clear: both; border:solid; border-width:1px; border-bottom-color:#007300; border-top-color:#ffffff; border-left-color:#ffffff; border-right-color:#ffffff;}
  .accesskey { text-decoration: underline; }
  img { border: 0; }
  a { text-decoration: none; }
</style>
</head>
<body>
<div class="header">
  <?php if ($logo) { ?><img src="<?php print $logo ?>" alt="logo" /><br /><?php } ?>
  <?php if (isset($primary_links)) { ?><?php print mobi_loader_primary_links($primary_links) ?><?php } ?>
</div>
<?php if ($sidebar_left) { ?><div class="sidebar-left"><?php print $sidebar_left ?></div><hr /><?php } ?>
<div class="content">
  <?php if ($breadcrumb) { print $breadcrumb; } ?>
  <?php if ($mission) { print $mission; } ?>
  <?php if ($title) { print '<h2>'. $title .'</h2>'; } ?>
  <?php if ($tabs) { print $tabs; } ?>
  <?php if (isset($tabs2)) { print $tabs2; } ?>
  <?php if ($help) { print $help; } ?>
  <?php if ($messages) { print $messages; } ?>
  <?php print $content ?>
  <?php print $feed_icons ?>
</div>
<?php if ($sidebar_right) { ?><hr /><div class="sidebar-right"><?php print $sidebar_right ?></div><?php } ?>
<div class="footer">
  <?php print $footer_message ?>
</div>
<?php print $closure; ?>
</body>
</html>

==> mobi-5.x-1.1.tar.gz: mobi/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//WAPFORUM//DTD XHTML Mobile 1.2//EN" "http://www.openmobilealliance.org/tech/DTD/xhtml-mobile11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php print $head_title ?></title>
<style type="text/css">
  hr { clear: both; border:solid; border-width:1px; border-bottom-color:#007300; border-top-color:#ffffff; border-left-color:#ffffff; border-right-color:#ffffff;}
  .accesskey { text-decoration: underline; }
  img { border: 0; }
  a { text-decoration: none; }
  .header { background-color: <?php print theme('mobi_loader_background_color', 'header', '#eef7fc') ?>; color: blue; border-bottom: solid 1px blue; margin: 0 0 5px 0; padding: 2px; }
  .content { background-color: <?php print theme('mobi_loader_background_color', 'content', '#ffffff') ?>; }
  .footer { background-color: <?php print theme('mobi_loader_background_color', 'footer', '#eef7fc') ?>; color: blue; border-top: solid 1px blue; margin: 10px 0 0 0; }
<?php if ($sidebar_left) { ?>
  .sidebar-left { background-color: <?php print theme('mobi_loader_background_color', 'left', '#ffffff') ?>; }
<?php } ?>
<?php if ($sidebar_right) { ?>
  .sidebar-right { background-color: <?php print theme('mobi_loader_background_color', 'right', '#ffffff') ?>; }
<?php } ?>
</style>
</head>
<body>
<div class="header">
  <?php if ($logo) { ?><img src="<?php print $logo ?>" alt="logo" /><br /><?php } ?>
  <?php if (isset($primary_links)) { ?><?php print theme('mobi_loader_primary_links', $primary_links) ?><?php } ?>
</div>
<?php if ($sidebar_left) { ?><div class="sidebar-left"><?php print $sidebar_left ?></div><hr /><?php } ?>
<div class="content">
  <?php if ($breadcrumb) { print $breadcrumb; } ?>
  <?php if ($mission) { print $mission; } ?>
  <?php if ($title) { print '<h2>'. $title .'</h2>'; } ?>
  <?php if ($tabs) { print $tabs; } ?>
  <?php if (isset($tabs2)) { print $tabs2; } ?>
  <?php if ($help) { print $help; } ?>
  <?php if ($messages) { print $messages; } ?>
  <?php print $content ?>
  <?php print $feed_icons ?>
</div>
<?php if ($sidebar_right) { ?><hr /><div class="sidebar-right"><?php print $sidebar_right ?></div><?php } ?>
<div class="footer">
  <?php print $footer_message ?>
</div>
<?php print $closure; ?>
</body>
</html>
